# tree-sitter-ocamllex

[![CI][ci]](https://github.com/314eter/tree-sitter-ocamllex/actions/workflows/ci.yml)
[![npm][npm]](https://www.npmjs.com/package/tree-sitter-ocamllex)
[![crates][crates]](https://crates.io/crates/tree-sitter-ocamllex)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-ocamllex/)

OCamllex grammar for [tree-sitter][].

### References

- [OCamllex Manual](https://ocaml.org/manual/lexyacc.html)
- [OCamllex parser](https://github.com/ocaml/ocaml/blob/trunk/lex/parser.mly)

[ci]: https://img.shields.io/github/actions/workflow/status/314eter/tree-sitter-ocamllex/ci.yml?logo=github&label=CI
[npm]: https://img.shields.io/npm/v/tree-sitter-ocamllex?logo=npm
[crates]: https://img.shields.io/crates/v/tree-sitter-ocamllex?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-ocamllex?logo=pypi&logoColor=white&label=PyPI
[tree-sitter]: https://tree-sitter.github.io/tree-sitter/
